@@ -1,6 +1,7 @@
 #' Get accepted names from tsn
 #' 
 #' @inheritParams getcommentdetailfromtsn
+#' @param verbose Verbosity or not (default TRUE)
 #' @examples \dontrun{
 #' # TSN accepted - good name
 #' getacceptednamesfromtsn('208527')
@@ -12,23 +13,21 @@
 #' getacceptednamesfromtsn('504239', FALSE) 
 #' }
 #' @export
-getacceptednamesfromtsn <- function(tsn = NA, ..., curl = getCurlHandle())
+#' @keywords internal
+getacceptednamesfromtsn <- function(tsn = NA, ..., curl = getCurlHandle(), verbose=TRUE)
 { 
 	url = "http://www.itis.gov/ITISWebService/services/ITISService/getAcceptedNamesFromTSN"
 	args <- list()
 	if(!is.na(tsn))
 		args$tsn <- tsn
-	tt <- getForm(url, 
-								.params = args, 
-								...,
-								curl = curl)
+	tt <- getForm(url, .params = args, ..., curl = curl)
 	tt_ <- xmlParse(tt)
 	temp <- xmlToList(tt_)
 	if(length(temp$return$acceptedNames) == 1) 
-	{ message("Good name!")
+	{ mssg(verbose, "Good name!")
 		temp$return$tsn
 	} else
-	{ message("Bad name!")
+	{ mssg(verbose, "Bad name!")
 		c(submittedTsn = temp$return$tsn, temp$return$acceptedNames[1:2])
 	}
 }
@@ -45,7 +44,8 @@ getacceptednamesfromtsn <- function(tsn = NA, ..., curl = getCurlHandle())
 #' getanymatchcount(202385)
 #' getanymatchcount("dolphin")
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getanymatchcount <- function(srchkey = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getAnyMatchCount'
@@ -72,6 +72,7 @@ getanymatchcount <- function(srchkey = NA, ..., curl = getCurlHandle() )
 #' getcommentdetailfromtsn(180543)
 #' }
 #' @export
+#' @keywords internal
 getcommentdetailfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getCommentDetailFromTSN'
@@ -104,14 +105,15 @@ getcommentdetailfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getcommonnamesfromtsn(183833)
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 getcommonnamesfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getCommonNamesFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
+  # message(paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
     ...,
@@ -135,7 +137,8 @@ getcommonnamesfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' getcoremetadatafromtsn(tsn = 28727)  # coverage and currrency data
 #' getcoremetadatafromtsn(tsn = 183671)  # no coverage or currrency data
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getcoremetadatafromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getCoreMetadataFromTSN'
@@ -165,7 +168,8 @@ getcoremetadatafromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' getcoveragefromtsn(tsn = 28727)  # coverage data
 #' getcoveragefromtsn(tsn = 526852)  # no coverage data
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getcoveragefromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getCoverageFromTSN'
@@ -194,7 +198,8 @@ getcoveragefromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getcredibilityratingfromtsn(tsn = 526852)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getcredibilityratingfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getCredibilityRatingFromTSN'
@@ -221,7 +226,8 @@ getcredibilityratingfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getcredibilityratings()
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 getcredibilityratings <- function() 
 {
 	url='http://www.itis.gov/ITISWebService/services/ITISService/getCredibilityRatings'
@@ -241,7 +247,8 @@ getcredibilityratings <- function()
 #' getcurrencyfromtsn(tsn = 28727) # currency data
 #' getcurrencyfromtsn(tsn = 526852) # no currency dat
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getcurrencyfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getCurrencyFromTSN'
@@ -270,7 +277,8 @@ getcurrencyfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getdatedatafromtsn(tsn = 180543)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getdatedatafromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getDateDataFromTSN'
@@ -299,16 +307,14 @@ getdatedatafromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getdescription()
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 getdescription <- function() 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getDescription'
-  message(url)
   tt <- getURL(url)
   out <- xmlParse(tt)
-  namespaces <- c(ax26="http://itis_service.itis.usgs.org/xsd")
-  nodes <- getNodeSet(out, "//ax26:description", namespaces=namespaces)
-  sapply(nodes, xmlValue)
+	getNodeSet(out, "//ns:return", fun=xmlValue)[[1]]
 }
 
 #' Get expert information for the TSN.
@@ -317,7 +323,8 @@ getdescription <- function()
 #' @examples \dontrun{
 #' getexpertsfromtsn(tsn = 180544)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getexpertsfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getExpertsFromTSN'
@@ -342,22 +349,25 @@ getexpertsfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 
 #' Get full hierarchy from tsn
 #' 
-#' @inheritParams getcommentdetailfromtsn
+#' @param tsn TSN for a taxonomic group (numeric)
+#' @param ... optional additional curl options (debugging tools mostly)
+#' @param curl If using in a loop, call getCurlHandle() first and pass 
+#'  the returned value in here (avoids unnecessary footprint)
 #' @examples \dontrun{
 #' getfullhierarchyfromtsn(tsn = 37906)
 #' getfullhierarchyfromtsn(tsn = 100800)
 #' }
-#' @export 
-getfullhierarchyfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal
+getfullhierarchyfromtsn <- function(tsn = NA, ..., curl = getCurlHandle()) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getFullHierarchyFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
-#     ...,
+    ...,
     curl = curl)
   out <- xmlParse(tt)
   namespaces <- c(namespaces <- c(ax21="http://data.itis_service.itis.usgs.gov/xsd"))
@@ -386,43 +396,77 @@ getfullhierarchyfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @param ... optional additional curl options (debugging tools mostly)
 #' @param curl If using in a loop, call getCurlHandle() first and pass 
 #'  the returned value in here (avoids unnecessary footprint) 
+#' @param verbose Verbosity or not (default TRUE)
 #' @examples \dontrun{
 #' getfullrecordfromlsid(lsid = "urn:lsid:itis.gov:itis_tsn:180543")
+#' getfullrecordfromlsid(lsid = "urn:lsid:itis.gov:itis_tsn:180543", verbose=FALSE)
 #' }
-#' @export 
-getfullrecordfromlsid <- function(lsid = NA, ..., curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+getfullrecordfromlsid <- function(lsid = NA, ..., curl = getCurlHandle(), verbose=TRUE) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getFullRecordFromLSID'
   args <- list()
   if(!is.na(lsid))
     args$lsid <- lsid
-  message(paste(url, '?lsid=', lsid, sep=''))
+  mssg(verbose, paste(url, '?lsid=', lsid, sep=''))
   tt <- getForm(url,
     .params = args,
     ...,
     curl = curl)
-  xmlParse(tt)
+  out <- xmlParse(tt)
+	namespaces <- c(ax21="http://data.itis_service.itis.usgs.gov/xsd")
+	toget <- c("acceptedNameList","commentList","commonNameList","completenessRating",
+	           "coreMetadata","credibilityRating","currencyRating","dateData","expertList",
+	           "geographicDivisionList","hierarchyUp","jurisdictionalOriginList",
+	           "kingdom","otherSourceList","parentTSN","publicationList","scientificName",
+	           "synonymList","taxRank","taxonAuthor","unacceptReason","usage")
+	parsedat <- function(x){
+	  tmp <- getNodeSet(out, sprintf("//ax21:%s",x), namespaces=namespaces, xmlToList)[[1]]
+	  tmp[!names(tmp) %in% ".attrs"]
+	}
+	temp <- lapply(toget, parsedat)
+	names(temp) <- toget
+	temp
 }
 
 #' Get full record from TSN.
 #' 
 #' @inheritParams getcommentdetailfromtsn
+#' @param verbose Verbosity or not (default TRUE)
 #' @examples \dontrun{
+#' getfullrecordfromtsn(tsn = 504239)
+#' getfullrecordfromtsn(tsn = 202385)
 #' getfullrecordfromtsn(tsn = 183833)
+#' getfullrecordfromtsn(tsn = 183833, verbose=FALSE)
 #' }
-#' @export 
-getfullrecordfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+getfullrecordfromtsn <- function(tsn = NA, ..., curl = getCurlHandle(), verbose=TRUE) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getFullRecordFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
+  mssg(verbose, paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
     ...,
     curl = curl)
-  xmlParse(tt)
+  out <- xmlParse(tt)
+	namespaces <- c(ax21="http://data.itis_service.itis.usgs.gov/xsd")
+  toget <- c("acceptedNameList","commentList","commonNameList","completenessRating",
+             "coreMetadata","credibilityRating","currencyRating","dateData","expertList",
+             "geographicDivisionList","hierarchyUp","jurisdictionalOriginList",
+             "kingdom","otherSourceList","parentTSN","publicationList","scientificName",
+             "synonymList","taxRank","taxonAuthor","unacceptReason","usage")
+	parsedat <- function(x){
+	  tmp <- getNodeSet(out, sprintf("//ax21:%s",x), namespaces=namespaces, xmlToList)[[1]]
+    tmp[!names(tmp) %in% ".attrs"]
+	}
+  temp <- lapply(toget, parsedat)
+  names(temp) <- toget
+  temp
 }
 
 #' Get geographic divisions from tsn
@@ -431,7 +475,8 @@ getfullrecordfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getgeographicdivisionsfromtsn(tsn = 180543)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getgeographicdivisionsfromtsn <- function(tsn = NA, ..., curl=getCurlHandle())
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getGeographicDivisionsFromTSN'
@@ -460,7 +505,8 @@ getgeographicdivisionsfromtsn <- function(tsn = NA, ..., curl=getCurlHandle())
 #' @examples \dontrun{
 #' getgeographicvalues()
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getgeographicvalues <- function() 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getGeographicValues'
@@ -479,7 +525,8 @@ getgeographicvalues <- function()
 #' @examples \dontrun{
 #' getglobalspeciescompletenessfromtsn(tsn = 180541)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getglobalspeciescompletenessfromtsn <- function(tsn = NA, ..., 
                                                 curl=getCurlHandle()) 
 {
@@ -506,17 +553,19 @@ getglobalspeciescompletenessfromtsn <- function(tsn = NA, ...,
 #' Get hierarchy down from tsn
 #' 
 #' @inheritParams getcommentdetailfromtsn
+#' @param verbose Verbosity or not (default TRUE)
 #' @examples \dontrun{
 #' gethierarchydownfromtsn(tsn = 161030)
 #' }
-#' @export 
-gethierarchydownfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+gethierarchydownfromtsn <- function(tsn = NA, ..., curl = getCurlHandle(), verbose = TRUE) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getHierarchyDownFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
+  mssg(verbose, paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
 #     ...,
@@ -540,17 +589,19 @@ gethierarchydownfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' Get hierarchy up from tsn
 #' 
 #' @inheritParams getcommentdetailfromtsn
+#' @param verbose Verbosity or not (default TRUE)
 #' @examples \dontrun{
 #' gethierarchyupfromtsn(tsn = 36485)
 #' }
-#' @export 
-gethierarchyupfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+gethierarchyupfromtsn <- function(tsn = NA, ..., curl = getCurlHandle(), verbose=TRUE) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getHierarchyUpFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
+  mssg(verbose, paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
     ...,
@@ -577,9 +628,9 @@ gethierarchyupfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getitistermsfromcommonname("buya")
 #' }
-#' @export 
-getitistermsfromcommonname <- function(srchkey = NA, ..., 
-                                       curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+getitistermsfromcommonname <- function(srchkey = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getITISTermsFromCommonName'
   args <- list()
@@ -591,15 +642,32 @@ getitistermsfromcommonname <- function(srchkey = NA, ...,
     curl = curl)
   out <- xmlParse(tt)
   namespaces <- c(namespaces <- c(ax21="http://data.itis_service.itis.usgs.gov/xsd"))
-  nodes <- getNodeSet(out, "//ax21:commonNames", namespaces=namespaces)
-  comname <- sapply(nodes, xmlValue)
-  nodes <- getNodeSet(out, "//ax21:nameUsage", namespaces=namespaces)
-  nameusage <- sapply(nodes, xmlValue)
-  nodes <- getNodeSet(out, "//ax21:scientificName", namespaces=namespaces)
-  sciname <- sapply(nodes, xmlValue)
-  nodes <- getNodeSet(out, "//ax21:tsn", namespaces=namespaces)
-  tsn <- sapply(nodes, xmlValue)
-  data.frame(comname=comname[-length(comname)], nameusage=nameusage, sciname=sciname, tsn=tsn)
+	gg <- getNodeSet(out, "//ax21:itisTerms", namespaces=namespaces, xmlToList)
+	do.call(rbind.fill, lapply(gg, function(x) data.frame(x,stringsAsFactors=FALSE)))  
+}
+
+#' Get itis terms from common names
+#' 
+#' @inheritParams getanymatchcount
+#' @examples \dontrun{
+#' getitisterms(srchkey="bear")
+#' }
+#' @export
+#' @keywords internal
+getitisterms <- function(srchkey = NA, ..., curl = getCurlHandle())
+{
+  url = 'http://www.itis.gov/ITISWebService/services/ITISService/getITISTerms'
+  args <- list()
+  if(!is.na(srchkey))
+    args$srchKey <- srchkey
+  tt <- getForm(url,
+                .params = args,
+                ...,
+                curl = curl)
+  out <- xmlParse(tt)
+  namespaces <- c(namespaces <- c(ax21="http://data.itis_service.itis.usgs.gov/xsd"))
+  gg <- getNodeSet(out, "//ax21:itisTerms", namespaces=namespaces, xmlToList)
+  do.call(rbind.fill, lapply(gg, function(x) data.frame(x,stringsAsFactors=FALSE)))
 }
 
 #' Get itis terms from scientific names
@@ -607,10 +675,11 @@ getitistermsfromcommonname <- function(srchkey = NA, ...,
 #' @inheritParams getanymatchcount
 #' @examples \dontrun{
 #' getitistermsfromscientificname(srchkey = "ursidae")
+#' getitistermsfromscientificname(srchkey = "Ursus")
 #' }
-#' @export 
-getitistermsfromscientificname <- function(srchkey = NA, ..., 
-                                           curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+getitistermsfromscientificname <- function(srchkey = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getITISTermsFromScientificName'
   args <- list()
@@ -623,32 +692,27 @@ getitistermsfromscientificname <- function(srchkey = NA, ...,
     curl = curl)
   out <- xmlParse(tt)
   namespaces <- c(namespaces <- c(ax21="http://data.itis_service.itis.usgs.gov/xsd"))
-  nodes <- getNodeSet(out, "//ax21:commonNames", namespaces=namespaces)
-  comname <- sapply(nodes, xmlValue)
-  nodes <- getNodeSet(out, "//ax21:nameUsage", namespaces=namespaces)
-  nameusage <- sapply(nodes, xmlValue)
-  nodes <- getNodeSet(out, "//ax21:scientificName", namespaces=namespaces)
-  sciname <- sapply(nodes, xmlValue)
-  nodes <- getNodeSet(out, "//ax21:tsn", namespaces=namespaces)
-  tsn <- sapply(nodes, xmlValue)
-  data.frame(comname=comname, nameusage=nameusage, sciname=sciname, tsn=tsn)
+	gg <- getNodeSet(out, "//ax21:itisTerms", namespaces=namespaces, xmlToList)
+	do.call(rbind.fill, lapply(gg, function(x) data.frame(x,stringsAsFactors=FALSE)))
 }
 
 #' Get jurisdictional origin from tsn
 #' 
 #' @inheritParams getcommentdetailfromtsn
+#' @param verbose Verbosity or not (default TRUE)
 #' @examples \dontrun{
-#' getjurisdictionaloriginfromtsn(tsn = 180543)
+#' getjurisdictionaloriginfromtsn(tsn = 2180543)
 #' }
-#' @export 
-getjurisdictionaloriginfromtsn <- function(tsn = NA, ..., 
-                                           curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+getjurisdictionaloriginfromtsn <- function(tsn = NA, ..., curl = getCurlHandle(), 
+                                           verbose=TRUE) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getJurisdictionalOriginFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
+  mssg(verbose, paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
     ...,
@@ -660,8 +724,13 @@ getjurisdictionaloriginfromtsn <- function(tsn = NA, ...,
     sapply(getNodeSet(out, paste("//ax21:", x, sep=''), namespaces=namespaces),xmlValue)
   }
   df <-  do.call(cbind, lapply(toget, as.data.frame(xpathfunc)))
-  names(df) <- toget
-  df
+  if(nrow(df) == 0){
+    data.frame(jurisdictionValue=NA,origin=NA,updateDate=NA)
+  } else
+  {
+    names(df) <- toget
+    df 
+  }
 }
 
 #' Get jurisdiction origin values
@@ -670,17 +739,18 @@ getjurisdictionaloriginfromtsn <- function(tsn = NA, ...,
 #' @examples \dontrun{
 #' getjurisdictionoriginvalues()
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 getjurisdictionoriginvalues <- function() 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getJurisdictionalOriginValues'
   message(url)
   tt <- getURL(url)
   out <- xmlParse(tt)
-  namespaces <- c(ax21="http://metadata.itis_service.itis.usgs.org/xsd" )
-  nodes <- getNodeSet(out, "//ax21:jurisdiction", namespaces=namespaces)
+  namespaces <- c(ax23="http://metadata.itis_service.itis.usgs.gov/xsd")
+  nodes <- getNodeSet(out, "//ax23:jurisdiction", namespaces=namespaces)
   jurisdiction <- sapply(nodes, xmlValue)
-  nodes <- getNodeSet(out, "//ax21:origin", namespaces=namespaces)
+  nodes <- getNodeSet(out, "//ax23:origin", namespaces=namespaces)
   origin <- sapply(nodes, xmlValue)
   data.frame(jurisdiction = jurisdiction, origin = origin)
 }
@@ -691,15 +761,16 @@ getjurisdictionoriginvalues <- function()
 #' @examples \dontrun{
 #' getjurisdictionvalues()
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 getjurisdictionvalues <- function() 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getJurisdictionValues'
   message(url)
   tt <- getURL(url)
   out <- xmlParse(tt)
-  namespaces <- c(ax21="http://metadata.itis_service.itis.usgs.org/xsd" )
-  nodes <- getNodeSet(out, "//ax21:jurisdictionValues", namespaces=namespaces)
+  namespaces <- c(ax23="http://metadata.itis_service.itis.usgs.gov/xsd")
+  nodes <- getNodeSet(out, "//ax23:jurisdictionValues", namespaces=namespaces)
   jurisdictionValues <- sapply(nodes, xmlValue)
   data.frame(jurisdictionValues = jurisdictionValues)
 }
@@ -707,17 +778,19 @@ getjurisdictionvalues <- function()
 #' Get kingdom names from tsn
 #' 
 #' @inheritParams getcommentdetailfromtsn
+#' @param verbose Verbosity or not (default TRUE)
 #' @examples \dontrun{
 #' getkingdomnamefromtsn(tsn = 202385)
 #' }
-#' @export 
-getkingdomnamefromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+getkingdomnamefromtsn <- function(tsn = NA, ..., curl = getCurlHandle(), verbose=TRUE) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getKingdomNameFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
+  mssg(verbose, paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
     ...,
@@ -737,9 +810,10 @@ getkingdomnamefromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' 
 #' @import RCurl XML
 #' @examples \dontrun{
-#' getkingdomnamefromtsn(tsn = 202385)
+#' getkingdomnames()
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 getkingdomnames <- function() 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getKingdomNames'
@@ -762,7 +836,8 @@ getkingdomnames <- function()
 #' @examples \dontrun{
 #' getlastchangedate()
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getlastchangedate <- function() 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getLastChangeDate'
@@ -780,7 +855,8 @@ getlastchangedate <- function()
 #' @examples \dontrun{
 #' getlsidfromtsn(tsn = 155166)
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 getlsidfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getLSIDFromTSN'
@@ -801,7 +877,8 @@ getlsidfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getothersourcesfromtsn(tsn = 182662)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getothersourcesfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getOtherSourcesFromTSN'
@@ -831,7 +908,8 @@ getothersourcesfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getparenttsnfromtsn(tsn = 202385)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getparenttsnfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getParentTSNFromTSN'
@@ -857,17 +935,19 @@ getparenttsnfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' Returns a list of the pulications used for the TSN.
 #' 
 #' @inheritParams getcommentdetailfromtsn
+#' @param verbose Verbosity or not (default TRUE)
 #' @examples \dontrun{
 #' getpublicationsfromtsn(tsn = 70340)
 #' }
-#' @export 
-getpublicationsfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+getpublicationsfromtsn <- function(tsn = NA, ..., curl = getCurlHandle(), verbose=TRUE) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getPublicationsFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
+  mssg(verbose, paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
     ...,
@@ -892,19 +972,19 @@ getpublicationsfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getranknames()
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 getranknames <- function() 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getRankNames'
-  message(url)
   tt <- getURL(url)
   out <- xmlParse(tt)
-  namespaces <- c(ax25="http://metadata.itis_service.itis.usgs.org/xsd")
-  nodes <- getNodeSet(out, "//ax25:kingdomName", namespaces=namespaces)
+  namespaces <- c(ax23="http://metadata.itis_service.itis.usgs.gov/xsd")
+  nodes <- getNodeSet(out, "//ax23:kingdomName", namespaces=namespaces)
   kingdomName <- sapply(nodes, xmlValue)
-  nodes <- getNodeSet(out, "//ax25:rankId", namespaces=namespaces)
+  nodes <- getNodeSet(out, "//ax23:rankId", namespaces=namespaces)
   rankId <- sapply(nodes, xmlValue)
-  nodes <- getNodeSet(out, "//ax25:rankName", namespaces=namespaces)
+  nodes <- getNodeSet(out, "//ax23:rankName", namespaces=namespaces)
   rankName <- sapply(nodes, xmlValue)
   data.frame(kingdomName = kingdomName, rankId = rankId, rankName = rankName)
 }
@@ -921,7 +1001,8 @@ getranknames <- function()
 #' @examples \dontrun{
 #' getrecordfromlsid(lsid = "urn:lsid:itis.gov:itis_tsn:180543")
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 getrecordfromlsid <- function(lsid = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getRecordFromLSID'
@@ -952,7 +1033,8 @@ getrecordfromlsid <- function(lsid = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getreviewyearfromtsn(tsn = 180541)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getreviewyearfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getReviewYearFromTSN'
@@ -982,14 +1064,15 @@ getreviewyearfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getscientificnamefromtsn(tsn = 531894)
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 getscientificnamefromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getScientificNameFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
+  # message(paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
     ...,
@@ -1008,19 +1091,22 @@ getscientificnamefromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 
 #' Returns a list of the synonyms (if any) for the TSN.
 #' 
-#' @inheritParams getcommentdetailfromtsn
+#' @param tsn TSN for a taxonomic group (numeric)
+#' @param ... optional additional curl options (debugging tools mostly)
+#' @param curl If using in a loop, call getCurlHandle() first and pass 
+#'  the returned value in here (avoids unnecessary footprint)
 #' @examples \dontrun{
 #' getsynonymnamesfromtsn(tsn = 183671) # tsn not accepted
 #' getsynonymnamesfromtsn(tsn = 526852) # tsn accepted
 #' }
-#' @export 
-getsynonymnamesfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+getsynonymnamesfromtsn <- function(tsn = NA, ..., curl = getCurlHandle()) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getSynonymNamesFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,.params = args,...,curl = curl)
   out <- xmlParse(tt)
   namespaces <- c(ax21="http://data.itis_service.itis.usgs.gov/xsd")
@@ -1042,7 +1128,8 @@ getsynonymnamesfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' gettaxonauthorshipfromtsn(tsn = 183671)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 gettaxonauthorshipfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getTaxonAuthorshipFromTSN'
@@ -1068,17 +1155,19 @@ gettaxonauthorshipfromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' Returns the kingdom and rank information for the TSN.
 #' 
 #' @inheritParams getcommentdetailfromtsn
+#' @param verbose Verbosity or not (default TRUE)
 #' @examples \dontrun{
 #' gettaxonomicranknamefromtsn(tsn = 202385)
 #' }
-#' @export 
-gettaxonomicranknamefromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal 
+gettaxonomicranknamefromtsn <- function(tsn = NA, ..., curl = getCurlHandle(), verbose = TRUE) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getTaxonomicRankNameFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
+  mssg(verbose, paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
      ...,
@@ -1096,18 +1185,23 @@ gettaxonomicranknamefromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 
 #' Returns the usage information for the TSN.
 #' 
-#' @inheritParams getcommentdetailfromtsn
+#' @param tsn TSN for a taxonomic group (numeric)
+#' @param ... optional additional curl options (debugging tools mostly)
+#' @param curl If using in a loop, call getCurlHandle() first and pass 
+#'  the returned value in here (avoids unnecessary footprint)
+#' @param verbose Verbosity or not (default TRUE)
 #' @examples \dontrun{
 #' gettaxonomicusagefromtsn(tsn = 526852)
 #' }
-#' @export 
-gettaxonomicusagefromtsn <- function(tsn = NA, ..., curl = getCurlHandle() ) 
+#' @export
+#' @keywords internal
+gettaxonomicusagefromtsn <- function(tsn = NA, ..., curl = getCurlHandle(), verbose = TRUE)
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getTaxonomicUsageFromTSN'
   args <- list()
   if(!is.na(tsn))
     args$tsn <- tsn
-  message(paste(url, '?tsn=', tsn, sep=''))
+  mssg(verbose, paste(url, '?tsn=', tsn, sep=''))
   tt <- getForm(url,
     .params = args,
     ...,
@@ -1134,7 +1228,8 @@ gettaxonomicusagefromtsn <- function(tsn = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' gettsnbyvernacularlanguage("french")
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 gettsnbyvernacularlanguage <- function(language = NA, ..., 
                                        curl = getCurlHandle() ) 
 {
@@ -1167,7 +1262,8 @@ gettsnbyvernacularlanguage <- function(language = NA, ...,
 #' gettsnfromlsid(lsid = "urn:lsid:itis.gov:itis_tsn:28726")
 #' gettsnfromlsid(lsid = "urn:lsid:itis.gov:itis_tsn:0")
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 gettsnfromlsid <- function(lsid = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getTSNFromLSID'
@@ -1191,7 +1287,8 @@ gettsnfromlsid <- function(lsid = NA, ..., curl = getCurlHandle() )
 #' @examples \dontrun{
 #' getunacceptabilityreasonfromtsn(tsn = 183671)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getunacceptabilityreasonfromtsn <- function(tsn = NA, ..., 
                                             curl = getCurlHandle() ) 
 {
@@ -1221,7 +1318,8 @@ getunacceptabilityreasonfromtsn <- function(tsn = NA, ...,
 #' @examples \dontrun{
 #' getvernacularlanguages()
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 getvernacularlanguages <- function() 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/getVernacularLanguages'
@@ -1242,7 +1340,8 @@ getvernacularlanguages <- function()
 #' searchbycommonname("ferret-badger")
 #' searchbycommonname(srchkey="polar bear")
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 searchbycommonname <- function(srchkey = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/searchByCommonName'
@@ -1264,13 +1363,36 @@ searchbycommonname <- function(srchkey = NA, ..., curl = getCurlHandle() )
   data.frame(comname=comname, lang=lang, tsn=tsn[-1])
 }
 
+
+#' Searches common name and acts as thin wrapper around \code{searchbycommonnamebeginswith} and \code{searchbycommonnameendswith}
+#' 
+#' @param srchkey search terms
+#' @param  ... additional arguments
+#' @param  curl  curl handle
+#' @param  from default is to search from beginning. Use \code{end} to serch from end.
+#' @seealso searchbycommonnamebeginswith searchbycommonnameendswith
+#' @return \code{data.frame}
+#' @examples \dontrun{
+#' searchCommon(srchkey="inch")
+#' searchCommon(srchkey="inch", from = "end")
+#'}
+itis_searchcommon <- function(srchkey = NA, ..., curl = getCurlHandle(), from = "begin") {
+switch(from, 
+   begin = searchbycommonnamebeginswith(srchkey = srchkey, ...),
+   end = searchbycommonnameendswith(srchkey = srchkey, ...),
+   )  
+}
+
+
+
 #' Search for tsn by common name beginning with 
 #' 
 #' @inheritParams getanymatchcount
 #' @examples \dontrun{
 #' searchbycommonnamebeginswith("inch")
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 searchbycommonnamebeginswith <- function(srchkey = NA, ..., 
                                          curl = getCurlHandle() ) 
 {
@@ -1300,7 +1422,8 @@ searchbycommonnamebeginswith <- function(srchkey = NA, ...,
 #' @examples \dontrun{
 #' searchbycommonnameendswith(srchkey="snake")
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 searchbycommonnameendswith <- function(srchkey = NA, ..., curl=getCurlHandle()) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/searchByCommonNameEndsWith'
@@ -1329,7 +1452,8 @@ searchbycommonnameendswith <- function(srchkey = NA, ..., curl=getCurlHandle())
 #' searchbyscientificname("Tardigrada")
 #' searchbyscientificname("Quercus douglasii")
 #' }
-#' @export 
+#' @export
+#' @keywords internal 
 searchbyscientificname <- function(srchkey = NA, ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/searchByScientificName'
@@ -1356,7 +1480,8 @@ searchbyscientificname <- function(srchkey = NA, ..., curl = getCurlHandle() )
 #' searchforanymatch(srchkey = 202385)
 #' searchforanymatch(srchkey = "dolphin")
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 searchforanymatch <- function(srchkey = NA,  ..., curl = getCurlHandle() ) 
 {
 	url = 'http://www.itis.gov/ITISWebService/services/ITISService/searchForAnyMatch'
@@ -1398,7 +1523,8 @@ searchforanymatch <- function(srchkey = NA,  ..., curl = getCurlHandle() )
 #' searchforanymatchpaged(srchkey=202385, pagesize=100, pagenum=1, ascend=FALSE)
 #' searchforanymatchpaged(srchkey="Zy", pagesize=100, pagenum=1, ascend=FALSE)
 #' }
-#' @export 
+#' @export
+#' @keywords internal
 searchforanymatchpaged <- function(srchkey = NA, pagesize = NA, pagenum = NA, 
                                    ascend = NA, ..., curl = getCurlHandle() ) 
 {
