@@ -13,6 +13,7 @@
 #' Currently not implemented - preference is given to ncbi.
 #' @param verbose logical; If TRUE the actual taxon queried is printed on the 
 #' console.
+#' @param ... Other arguments passed to \code{\link[taxize]{get_tsn}} or \code{\link[taxize]{get_uid}}.
 #' 
 #' @return A data.frame with one column for every queried rank.
 #' 
@@ -42,7 +43,7 @@
 #' }
 #' @export
 tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi', 
-                     verbose = TRUE)
+                     verbose = TRUE, ...)
 {
   if(is.null(query))
     stop('Need to specify query!\n')
@@ -53,17 +54,17 @@ tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi',
   if(db == 'both' & !pref %in% c('ncbi', 'itis'))
     stop("if db=both, pref must be either 'itis' or 'ncbi'!\n")
   
-  fun <- function(query, get, db, verbose){
+  fun <- function(query, get, db, verbose, ...){
     # ITIS
   	if(db == "itis"){
-  		tsn <- get_tsn(query, searchtype = "sciname", verbose = verbose)
+  		tsn <- get_tsn(query, searchtype = "sciname", verbose = verbose, ...)
       if(is.na(tsn)) {
         if(verbose) 
           message("No TSN found for species '", query, "'!\n")
         out <- data.frame(t(rep(NA, length(get))))
         names(out) <- get
       } else {
-        tt <- classification(tsn)[[1]]
+        tt <- classification(tsn, ...)[[1]]
         out <- as.character(tt[tolower(tt$rankName) %in% tolower(get), "taxonName"])
         if(length(out) == 0)
           out <- data.frame(t(rep(NA, length(get))))
@@ -74,14 +75,14 @@ tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi',
     
     # NCBI
   	if(db == "ncbi")	{
-  		uid <- get_uid(query, verbose = verbose)
+  		uid <- get_uid(query, verbose = verbose, ...)
       if(is.na(uid)){
         if(verbose) 
           message("No UID found for species '", query, "'!\n")
         out <- data.frame(t(rep(NA, length(get))))
         names(out) <- get
       } else {
-  			hierarchy <- classification(uid)[[1]]
+  			hierarchy <- classification(uid, ...)[[1]]
   			match <- hierarchy$ScientificName[match(tolower(get), tolower(hierarchy$Rank))]
         out <- data.frame(t(match), stringsAsFactors=FALSE)
         names(out) <- get
@@ -91,17 +92,17 @@ tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi',
     # combine both
       # NCBI
     if(db == 'both') {
-      uid <- get_uid(query, verbose = verbose)
+      uid <- get_uid(query, verbose = verbose, ...)
       if(is.na(uid)){
         if(verbose) 
           message("No UID found for species '", query, "'!\n")
         match_uid <- rep(NA, length(get))
       } else {
-        hierarchy <- classification(uid)[[1]]
+        hierarchy <- classification(uid, ...)[[1]]
         match_uid <- hierarchy$ScientificName[match(tolower(get), tolower(hierarchy$Rank))]
       }
       # itis
-      tsn <- get_tsn(query, searchtype="sciname", verbose = verbose)
+      tsn <- get_tsn(query, searchtype="sciname", verbose = verbose, ...)
       if(is.na(tsn)) {
         if(verbose) 
           message("No TSN found for species '", query, "'!\n")
@@ -116,6 +117,6 @@ tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi',
     }
     return(out)
   }
-  out <- ldply(query, .fun = function(x) fun(query = x, get = get, db = db, verbose = verbose))
+  out <- ldply(query, .fun = fun, get, db, verbose, ...)
   return(out)
 }
\ No newline at end of file
